Changelog
=========

v0.2.0
-------------------------------------------

Integrate the pytest-oot plugin, all functionalities in pytest-oot will be here.

* support .oot pytest file for object-oriented testing and more.



v0.1.2
-------------------------------------------

A simple plugin for py.test. test-steps package is required.

* automatically log test cases and steps
* use py.test mechanism to start log function
